@@ -38,6 +38,16 @@ public:
 		errorMessage();
 	}
 
+	template<typename SomeMapType>
+	void setMap(SomeMapType&) const
+	{
+		errorMessage();
+	}
+
+	void expandMacrosRecursively()
+	{
+		errorMessage();
+	}
 private:
 
 	void errorMessage() const
