@@ -517,12 +517,13 @@ public:
 
 	class Readable {
 
-		typedef typename Map<String,String,MyCompareType>::Type::iterator MapStringIteratorType;
+	public:
+
+		typedef typename Map<String, String, MyCompareType>::Type MapStringStringType;
+		typedef typename MapStringStringType::iterator MapStringIteratorType;
 		typedef typename Map<String,Vector<String>::Type,MyCompareType>::Type::iterator
 		MapStringVectorIteratorType;
 
-	public:
-
 		Readable(const Writeable& inputWriteable)
 		    : file_(inputWriteable.filename()),
 		      data_(inputWriteable.data()),
@@ -538,6 +539,8 @@ public:
 				}
 
 				ainur_ = new Ainur(inputWriteable.inputCheck().import() + data_);
+				ainur_->expandMacrosRecursively();
+				ainur_->setMap(mapStrStr_);
 			}
 		}
 
@@ -547,14 +550,6 @@ public:
 			ainur_ = 0;
 		}
 
-		template<typename SomeMemResolvType>
-		SizeType memResolv(SomeMemResolvType&,
-		                   SizeType,
-		                   String = "") const
-		{
-			return 0;
-		}
-
 		void rewind() {}
 
 		bool isAinur() const { return (ainur_ != nullptr); }
@@ -849,6 +844,11 @@ public:
 			throw RuntimeError("InputNg: Matrix<String> not supported in POD inputs\n");
 		}
 
+		MapStrStrType map() const
+		{
+			return mapStrStr_;
+		}
+
 		const String& filename() const
 		{
 			return file_;
@@ -1000,7 +1000,7 @@ public:
 		String file_;
 		String data_;
 		//serializr normal mapStrStr_
-		typename Map<String,String,MyCompareType>::Type mapStrStr_;
+		MapStringStringType mapStrStr_;
 		//serializr normal mapStrVec_
 		typename Map<String,Vector<String>::Type,MyCompareType>::Type mapStrVec_;
 		//serializr normal labelsForRemoval_
